@@ -38,16 +38,13 @@ Q_OBJECT
 		void keyPressEvent(QKeyEvent *e) override;
 		void keyReleaseEvent(QKeyEvent *e) override;
 		
-	private slots:
+	private Q_SLOTS:
 		void checkHS();
 		void highlight(blinkenGame::color c, bool unhighlight);
 		void unhighlight();
 		
-		void pressedYellow();
-		void pressedRed();
-		void pressedGreen();
-		void pressedBlue();
-		
+		void pressedColor(blinkenGame::color c);
+
 	private:
 		void startGamePressed();
 		void startGameAtLevel(int level);
